# -*- coding:Utf-8 -*-
import es, re, psyco, random, weaponlib
psyco.full()


regex = re.compile('//.*|(\r)+|(\n)+|(")+|')

class DmWeapon(object):
    """ Weapon Management """

    def __init__(self):
        self.pistol = []
        self.shotgun = []
        self.smg = []
        self.rifle = []
        self.sniper = []
        self.grenade = []
        self.allowed = []
        
        self.weaponfile = es.getString("eventscripts_gamedir") + "/cfg/dm_python/weapons.txt"
        self.weaponlist = [
            "glock", "usp", "p228", "deagle", "fiveseven", "elite",
            "m3", "xm1014",
            "tmp", "mac10", "mp5navy", "ump45", "p90",
            "galil", "famas", "ak47", "m4a1", "sg552", "aug", "m249",
            "scout", "awp", "g3sg1", "sg550",
            "hegrenade", "flashbang", "smokegrenade"]

    def __getitem__(self, item):
        weaponInfo = weaponlib.getWeapon(item)
        if weaponInfo is None: return None
        weaponTags = weaponInfo.tags
        if "#pistol" in weaponTags: return self.pistol
        elif "#shotgun" in weaponTags: return self.shotgun
        elif "#smg" in weaponTags: return self.smg
        elif "#sniper" in weaponTags: return self.sniper
        elif "#rifle" in weaponTags or "#machinegun" in weaponTags: return self.rifle
        elif "#grenade" in weaponTags: return self.grenade

    def __add__(self, item):
        weaponList = self[item]
        if weaponList is not None:
            if not item in weaponList: weaponList.append(item)
            if not item in self.allowed: self.allowed.append(item)

    def __sub__(self, item):
        weaponList = self[item]
        if weaponList is not None:
            if item in weaponList: weaponList.remove(item)
            if item in self.allowed: self.allowed.remove(item)

    def __contains__(self, item):
        return item in self.allowed

    def i_read(self):
        try:
            openfile = open(self.weaponfile, "rb")
            lines = [line for line in map(lambda line: regex.sub("", line).strip(), openfile.readlines()) if line]
            openfile.close()
            return lines
        except IOError:
            es.dbgmsg(0, "dm_python: cannot read file cfg/dm_python/weapons.txt" % filepath)
            return []

    def save(self):
        try:
            config = open(self.weaponfile, "w")
            config.write('// weapon.txt for dm_python script\n// add "//" for restrict a weapon\n\n')
            for weapon in self.weaponlist: config.write("\n" + weapon if self.__contains__(weapon) else "\n// " + weapon )
            config.close()
        except IOError: es.dbgmsg(0, "dm_python: cannot read file cfg/dm_python/weapons.txt")

    def read(self):
        self.pistol, self.shotgun, self.smg, self.rifle, self.sniper, self.grenade = [], [], [], [], [], []
        for weaponName in self.i_read(): self.__add__(weaponName)
        self.allowed = self.pistol + self.shotgun + self.smg + self.rifle + self.sniper + self.grenade

    def botPrimary(self):
        weaponBots = es.getString("dp_bot_primary")
        if weaponBots <> "0":
            weaponList = [weaponName for weaponName in map(lambda weaponName: weaponName.strip(), weaponBots.split(",")) if self.__contains__(weaponName) is not None]
            if weaponList: return random.choice(weaponList)
        primary = self.shotgun + self.smg + self.rifle + self.sniper
        return random.choice(primary) if primary else None

    def botSecondary(self):
        weaponBots = es.getString("dp_bot_secondary")
        if weaponBots <> "0":
            weaponList = [weaponName for weaponName in map(lambda weaponName: weaponName.strip(), weaponBots.split(",")) if self.__contains__(weaponName) is not None]
            if weaponList: return random.choice(weaponList)
        return random.choice(self.pistol) if self.pistol else None
